@@ -21,7 +21,9 @@
 **  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 **  USA, or contact Ralf S. Engelschall <rse@engelschall.com>.
 */
-
+                             /* Steinbach's Guideline for Systems Programming:
+                                ``Never test for an error condition 
+                                  you don't know how to handle.''            */
 #include "pth_p.h"
 
 #if cpp
@@ -32,7 +34,7 @@
 #define errno_restore \
         do { errno = pth_errno_storage; } while (0)
 #define errno_safe(cmd) \
-        do { int __local_errno = errno; (cmd); errno = __local_errno; } while (0)
+        do { int __local_errno = errno; cmd; errno = __local_errno; } while (0)
 
 /* return plus setting an errno value */
 #if defined(PTH_DEBUG)
