@@ -85,6 +85,8 @@ intern void pth_pqueue_insert(pth_pqueue_t *q, int prio, pth_t t)
         t->q_prev->q_next = t;
         t->q_next->q_prev = t;
         t->q_prio = p - prio;
+        if (t->q_next != q->q_head)
+            t->q_next->q_prio -= t->q_prio;
     }
     q->q_num++;
     return;
@@ -148,7 +150,8 @@ intern void pth_pqueue_delete(pth_pqueue_t *q, pth_t t)
     else {
         t->q_prev->q_next = t->q_next;
         t->q_next->q_prev = t->q_prev;
-        t->q_next->q_prio = t->q_prio - t->q_next->q_prio;
+        if (t->q_next != q->q_head)
+            t->q_next->q_prio += t->q_prio;
         q->q_num--;
     }
     return;
