@@ -26,20 +26,20 @@
                                      -- Unknown   */
 #include "pth_p.h"
 
-intern pth_t        pth_main;       /* the main thread */
-intern pth_t        pth_sched;      /* the permanent scheduler thread */
-intern pth_t        pth_current;    /* the currently running thread */
-intern pth_pqueue_t pth_NQ;         /* queue of new threads */
-intern pth_pqueue_t pth_RQ;         /* queue of threads ready to run */
+intern pth_t        pth_main;       /* the main thread                       */
+intern pth_t        pth_sched;      /* the permanent scheduler thread        */
+intern pth_t        pth_current;    /* the currently running thread          */
+intern pth_pqueue_t pth_NQ;         /* queue of new threads                  */
+intern pth_pqueue_t pth_RQ;         /* queue of threads ready to run         */
 intern pth_pqueue_t pth_WQ;         /* queue of threads waiting for an event */
-intern pth_pqueue_t pth_DQ;         /* queue of terminated threads */
-intern float        pth_loadval;    /* average scheduler load value */
+intern pth_pqueue_t pth_DQ;         /* queue of terminated threads           */
+intern float        pth_loadval;    /* average scheduler load value          */
 
-static int          pth_sigpipe[2]; /* internal signal occurrence pipe */
-static sigset_t     pth_sigpending; /* mask of pending signals */
+static int          pth_sigpipe[2]; /* internal signal occurrence pipe       */
+static sigset_t     pth_sigpending; /* mask of pending signals               */
 static sigset_t     pth_sigblock;   /* mask of signals we block in scheduler */
-static sigset_t     pth_sigcatch;   /* mask of signals we have to catch */
-static sigset_t     pth_sigraised;  /* mask of raised signals */
+static sigset_t     pth_sigcatch;   /* mask of signals we have to catch      */
+static sigset_t     pth_sigraised;  /* mask of raised signals                */
 
 static pth_time_t   pth_loadticknext;
 static pth_time_t   pth_loadtickgap = PTH_TIME(1,0);
@@ -110,36 +110,34 @@ intern void pth_scheduler_kill(void)
     return;
 } 
 
-/* update the average scheduler load */
-intern void pth_scheduler_load(pth_time_t *now)
-{
-    pth_time_t t;
-    int numready;
-
-    /*
-     * We're called on every context switch, but we have to adjust the average
-     * load value every second, only. When we're called more than once per
-     * second we handle this by just calculating anything once and then do
-     * NOPs until the next ticks is over.  When the scheduler waited for more
-     * than once second (or a thread CPU burst lasted for more than once
-     * second) we simulate the missing calculations. That's no problem because
-     * we can assume that the number of ready threads then wasn't changed
-     * dramatically (or more context switched would have been occurred and we
-     * would have been given more chances to operate). The actual average load
-     * is calculated through an exponential average formula.
-     */
-    if (pth_time_cmp(now, &pth_loadticknext) >= 0) {
-        numready = pth_pqueue_elements(&pth_RQ);
-        pth_time_set(&t, now);
-        do {
-            pth_loadval = (numready*0.25) + (pth_loadval*0.75);
-            pth_time_sub(&t, &pth_loadtickgap);
-        } while (pth_time_cmp(&t, &pth_loadticknext) >= 0);
-        pth_time_set(&pth_loadticknext, now);
-        pth_time_add(&pth_loadticknext, &pth_loadtickgap);
+/* 
+ * Update the average scheduler load.
+ *
+ * This is called on every context switch, but we have to adjust the
+ * average load value every second, only. When we're called more than
+ * once per second we handle this by just calculating anything once
+ * and then do NOPs until the next ticks is over. When the scheduler
+ * waited for more than once second (or a thread CPU burst lasted for
+ * more than once second) we simulate the missing calculations. That's
+ * no problem because we can assume that the number of ready threads
+ * then wasn't changed dramatically (or more context switched would have
+ * been occurred and we would have been given more chances to operate).
+ * The actual average load is calculated through an exponential average
+ * formula.
+ */
+#define pth_scheduler_load(now) \
+    if (pth_time_cmp((now), &pth_loadticknext) >= 0) { \
+        pth_time_t ttmp; \
+        int numready; \
+        numready = pth_pqueue_elements(&pth_RQ); \
+        pth_time_set(&ttmp, (now)); \
+        do { \
+            pth_loadval = (numready*0.25) + (pth_loadval*0.75); \
+            pth_time_sub(&ttmp, &pth_loadtickgap); \
+        } while (pth_time_cmp(&ttmp, &pth_loadticknext) >= 0); \
+        pth_time_set(&pth_loadticknext, (now)); \
+        pth_time_add(&pth_loadticknext, &pth_loadtickgap); \
     }
-    return;
-}
 
 /* the heart of this library: the thread scheduler */
 intern void *pth_scheduler(void *dummy)
@@ -177,8 +175,8 @@ intern void *pth_scheduler(void *dummy)
          */
         while ((t = pth_pqueue_delmax(&pth_NQ)) != NULL) {
             t->state = PTH_STATE_READY;
-            pth_pqueue_insert(&pth_RQ, PTH_PRIO_MAX, t);
-            pth_debug2("pth_scheduler: new thread \"%s\" moved to ready queue", t->name);
+            pth_pqueue_insert(&pth_RQ, pth_pqueue_favorite_prio(&pth_RQ), t);
+            pth_debug2("pth_scheduler: new thread \"%s\" moved to top of ready queue", t->name);
         }
 
         /*
