@@ -288,7 +288,7 @@ int pthread_create(
     return OK;
 }
 
-int pthread_detach(pthread_t thread)
+int __pthread_detach(pthread_t thread)
 {
     pth_attr_t na;
 
@@ -992,86 +992,86 @@ int pthread_abort(pthread_t thread)
 **  THREAD-SAFE REPLACEMENT FUNCTIONS
 */
 
-pid_t _pthread_fork(void)
+pid_t __pthread_fork(void)
 {
     pthread_initialize();
     return pth_fork();
 }
 
-unsigned int _pthread_sleep(unsigned int sec)
+unsigned int __pthread_sleep(unsigned int sec)
 {
     pthread_initialize();
     return pth_sleep(sec);
 }
 
-int _pthread_sigwait(const sigset_t *set, int *sig)
+int __pthread_sigwait(const sigset_t *set, int *sig)
 {
     pthread_initialize();
     return pth_sigwait(set, sig);
 }
 
-pid_t _pthread_waitpid(pid_t pid, int *status, int options)
+pid_t __pthread_waitpid(pid_t pid, int *status, int options)
 {
     pthread_initialize();
     return pth_waitpid(pid, status, options);
 }
 
-int _pthread_connect(int s, struct sockaddr *addr, int addrlen)
+int __pthread_connect(int s, struct sockaddr *addr, int addrlen)
 {
     pthread_initialize();
     return pth_connect(s, addr, addrlen);
 }
 
-int _pthread_accept(int s, struct sockaddr *addr, int *addrlen)
+int __pthread_accept(int s, struct sockaddr *addr, int *addrlen)
 {
     pthread_initialize();
     return pth_accept(s, addr, addrlen);
 }
 
-int _pthread_select(int nfds, fd_set *readfds, fd_set *writefds, 
+int __pthread_select(int nfds, fd_set *readfds, fd_set *writefds, 
                     fd_set *exceptfds, struct timeval *timeout)
 {
     pthread_initialize();
     return pth_select(nfds, readfds, writefds, exceptfds, timeout);
 }
 
-int _pthread_poll(struct pollfd *pfd, unsigned int nfd, int timeout)
+int __pthread_poll(struct pollfd *pfd, unsigned int nfd, int timeout)
 {
     pthread_initialize();
     return pth_poll(pfd, nfd, timeout);
 }
 
-ssize_t _pthread_read(int fd, void *buf, size_t nbytes)
+ssize_t __pthread_read(int fd, void *buf, size_t nbytes)
 {
     pthread_initialize();
     return pth_read(fd, buf, nbytes);
 }
 
-ssize_t _pthread_write(int fd, const void *buf, size_t nbytes)
+ssize_t __pthread_write(int fd, const void *buf, size_t nbytes)
 {
     pthread_initialize();
     return pth_write(fd, buf, nbytes);
 }
 
-ssize_t _pthread_readv(int fd, const struct iovec *piovec, int iocnt)
+ssize_t __pthread_readv(int fd, const struct iovec *piovec, int iocnt)
 {
     pthread_initialize();
     return pth_readv(fd, piovec, iocnt);
 }
 
-ssize_t _pthread_writev(int fd, const struct iovec *piovec, int iocnt)
+ssize_t __pthread_writev(int fd, const struct iovec *piovec, int iocnt)
 {
     pthread_initialize();
     return pth_writev(fd, piovec, iocnt);
 }
 
-ssize_t _pthread_pread(int fd, void *buf, size_t nbytes, off_t offset)
+ssize_t __pthread_pread(int fd, void *buf, size_t nbytes, off_t offset)
 {
     pthread_initialize();
     return pth_pread(fd, buf, nbytes, offset);
 }
 
-ssize_t _pthread_pwrite(int fd, const void *buf, size_t nbytes, off_t offset)
+ssize_t __pthread_pwrite(int fd, const void *buf, size_t nbytes, off_t offset)
 {
     pthread_initialize();
     return pth_pwrite(fd, buf, nbytes, offset);
